@@ -98,6 +98,10 @@ foreach $s (split(/\s+/, $_[0]->{'cluster_server'})) {
 		# This server
 		push(@run, ( { 'desc' => $text{'edit_this'} } ));
 		}
+	elsif ($s eq 'ALL') {
+		# All servers with users
+		push(@run, grep { $_->{'user'} } @servers);
+		}
 	else {
 		# A single remote server
 		push(@run, grep { $_->{'host'} eq $s } @servers);
@@ -113,7 +117,7 @@ $inst_error_msg = join("", @_);
 &remote_error_setup(\&inst_error);
 
 # Create a local temp file containing input
-local $ltemp = &tempname();
+local $ltemp = &transname();
 open(TEMP, ">$ltemp");
 local $inp = $_[0]->{'cluster_input'};
 $inp =~ s/\\%/\0/g;
